@@ -1,7 +1,7 @@
 
 package OODoc::Format;
 use vars '$VERSION';
-$VERSION = '0.07';
+$VERSION = '0.08';
 use base 'OODoc::Object';
 
 use strict;
@@ -462,5 +462,24 @@ sub showSuperSupers($)
 #-------------------------------------------
 
 
+sub zoneGetParameters($)
+{   my ($self, $zone) = @_;
+    my $param = ref $zone ? $zone->attributes : $zone;
+    $param =~ s/^\s+//;
+    $param =~ s/\s+$//;
+
+    return () unless length $param;
+
+    return split / /, $param       # old style
+       unless $param =~ m/[^\s\w]/;
+
+    # new style
+    my @params = split /\s*\,\s*/, $param;
+    map { (split /\s*\=\>\s*/, $_, 2) } @params;
+}
+
+#-------------------------------------------
+
+
 1;
 
