@@ -1,7 +1,7 @@
 
 package OODoc::Format::Pod2;
 use vars '$VERSION';
-$VERSION = '0.07';
+$VERSION = '0.08';
 use base 'OODoc::Format::Pod';
 
 use strict;
@@ -37,11 +37,11 @@ sub formatManual(@)
     my $output    = delete $args{output};
 
     my %permitted =
-     ( chapter     => sub {$self->templateChapter(\@_, \%args) }
-     , inheritance => sub {$self->templateInheritance(\@_, \%args) }
-     , diagnostics => sub {$self->templateDiagnostics(\@_, \%args) }
-     , append      => sub {$self->templateAppend(\@_, \%args) }
-     , comment     => sub {}
+     ( chapter     => sub {$self->templateChapter(shift, \%args) }
+     , inheritance => sub {$self->templateInheritance(shift, \%args) }
+     , diagnostics => sub {$self->templateDiagnostics(shift, \%args) }
+     , append      => sub {$self->templateAppend(shift, \%args) }
+     , comment     => sub { '' }
      );
 
     my $template  = Text::MagicTemplate->new
@@ -56,19 +56,20 @@ sub formatManual(@)
 
 
 sub templateChapter($$)
-{   my ($self, $attr, $args) = @_;
-    my ($contained, $attributes) = @$attr;
-    my $name = $attributes =~ s/^\s*(\w+)\b// ? $1 : undef;
+{   my ($self, $zone, $args) = @_;
+    my $contained = $zone->content;
+    warn "WARNING: no meaning for container $contained in chapter block\n"
+        if defined $contained && length $contained;
+
+    my $attrs = $zone->attributes;
+    my $name  = $attrs =~ s/^\s*(\w+)\s*\,?// ? $1 : undef;
 
     croak "ERROR: chapter without name in template.", return ''
        unless defined $name;
 
-    warn "WARNING: no meaning for container $contained in chapter block\n"
-        if defined $contained && length $contained;
-
-    my @attrs = split " ", $attributes;
-
+    my @attrs = $self->zoneGetParameters($attrs);
     my $out   = '';
+
     $self->showOptionalChapter($name, %$args,
        output => IO::Scalar->new(\$out), @attrs);
 
@@ -78,7 +79,7 @@ sub templateChapter($$)
 #-------------------------------------------
 
 sub templateInheritance($$)
-{   my ($self, $attr, $args) = @_;
+{   my ($self, $zone, $args) = @_;
     my $out   = '';
     $self->chapterInheritance(%$args, output => IO::Scalar->new(\$out));
     $out;
@@ -87,7 +88,7 @@ sub templateInheritance($$)
 #-------------------------------------------
 
 sub templateDiagnostics($$)
-{   my ($self, $attr, $args) = @_;
+{   my ($self, $zone, $args) = @_;
     my $out   = '';
     $self->chapterDiagnostics(%$args, output => IO::Scalar->new(\$out));
     $out;
@@ -96,7 +97,7 @@ sub templateDiagnostics($$)
 #-------------------------------------------
 
 sub templateAppend($$)
-{   my ($self, $attr, $args) = @_;
+{   my ($self, $zone, $args) = @_;
     my $out   = '';
     $self->showAppend(%$args, output => IO::Scalar->new(\$out));
     $out;
